@@ -2,17 +2,24 @@
 import os, time
 import threading
 
-from .detach import detach_pickup
-
 ##__________________________________________________________________||
 class ProgressReportPickup(threading.Thread):
     """A pickup of progress reports.
 
     This class picks up progress reports and presents them.
 
+    Parameters
+    ----------
+    queue : multiprocessing.Queue
+        The queue through which this class receives progress reports
+    presentation :
+        The presentation of the reports
     """
     def __init__(self, queue, presentation):
-        threading.Thread.__init__(self)
+        super().__init__(daemon=True)
+        # The daemon makes the functions registered at atexit called
+        # even if the pickup is still running
+
         self.queue = queue
         self.presentation = presentation
         self.last_wait_time = 1.0 # [second]
@@ -27,43 +34,42 @@ class ProgressReportPickup(threading.Thread):
 
     def _run_until_the_end_order_arrives(self):
         end_order_arrived = False
-        while not end_order_arrived:
+        while True:
             while not self.queue.empty():
                 report = self.queue.get()
                 if report is None: # the end order
                     end_order_arrived = True
                     continue
                 self._process_report(report)
-            time.sleep(0.001)
+            if end_order_arrived:
+                break
+            else:
+                self._short_sleep()
 
     def _run_until_reports_stop_coming(self):
-        self._read_time()
+        self.last_time = time.time()
         while self.presentation.active():
-            if self._time() - self.last_time > self.last_wait_time:
+            if time.time() - self.last_time > self.last_wait_time:
                 break
             while not self.queue.empty():
                 report = self.queue.get()
                 if report is None:
                     continue
-                self._read_time()
+                self.last_time = time.time()
                 self._process_report(report)
+            self._short_sleep()
 
     def _process_report(self, report):
-        self._detach_self_if_necessary(report)
         self.presentation.present(report)
 
-    def _detach_self_if_necessary(self, report):
-        if report['taskid'] in self.taskids:
-            return
-        self.taskids.add(report['taskid'])
-        if os.getpid() == report['pid'] and report['in_main_thread']:
-            return
-        detach_pickup()
+    def _short_sleep(self):
+        """sleep very briefly
 
-    def _time(self):
-        return time.time()
+        used to prevent the empty `while` loop from increasing CPU
+        loads
+
+        """
+        time.sleep(0.001)
 
-    def _read_time(self):
-        self.last_time = self._time()
 
 ##__________________________________________________________________||
